'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

exports.getObjectFromUrl = getObjectFromUrl;
exports.getObjectFromTypeAndId = getObjectFromTypeAndId;
exports.getObjectsByType = getObjectsByType;

var _dataloader = require('dataloader');

var _dataloader2 = _interopRequireDefault(_dataloader);

var _api = require('../api');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 *  Copyright (c) 2015, Facebook Inc.
 *  All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 */

var localUrlLoader = new _dataloader2.default(function (urls) {
  return _promise2.default.all(urls.map(_api.getFromLocalUrl));
});

/**
 * Objects returned from SWAPI don't have an ID field, so add one.
 */
function objectWithId(obj) {
  obj.id = obj.url.split('/')[5];
  return obj;
}

/**
 * Given an object URL, fetch it, append the ID to it, and return it.
 */
function getObjectFromUrl(url) {
  var dataString, data;
  return _regenerator2.default.async(function getObjectFromUrl$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return _regenerator2.default.awrap(localUrlLoader.load(url));

        case 2:
          dataString = _context.sent;
          data = JSON.parse(dataString);
          return _context.abrupt('return', objectWithId(data));

        case 5:
        case 'end':
          return _context.stop();
      }
    }
  }, null, this);
}

/**
 * Given a type and ID, get the object with the ID.
 */
function getObjectFromTypeAndId(type, id) {
  return _regenerator2.default.async(function getObjectFromTypeAndId$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          _context2.next = 2;
          return _regenerator2.default.awrap(getObjectFromUrl('http://swapi.co/api/' + type + '/' + id + '/'));

        case 2:
          return _context2.abrupt('return', _context2.sent);

        case 3:
        case 'end':
          return _context2.stop();
      }
    }
  }, null, this);
}

/**
 * Quick helper method, if the user just passes `first`, we can stop
 * fetching once we have that many items.
 */
function doneFetching(objects, args) {
  if (!args || args.after || args.before || args.last || !args.first) {
    return false;
  }
  return objects.length >= args.first;
}

/**
 * Given a type, fetch all of the pages, and join the objects together
 */
function getObjectsByType(type, args) {
  var objects, totalCount, nextUrl, pageData, parsedPageData;
  return _regenerator2.default.async(function getObjectsByType$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          objects = [];
          totalCount = 0;
          nextUrl = 'http://swapi.co/api/' + type + '/';

        case 3:
          if (!(nextUrl && !doneFetching(objects, args))) {
            _context3.next = 13;
            break;
          }

          _context3.next = 6;
          return _regenerator2.default.awrap(localUrlLoader.load(nextUrl));

        case 6:
          pageData = _context3.sent;
          parsedPageData = JSON.parse(pageData);

          totalCount = parsedPageData.count;
          objects = objects.concat(parsedPageData.results.map(objectWithId));
          nextUrl = parsedPageData.next;
          _context3.next = 3;
          break;

        case 13:
          return _context3.abrupt('return', { objects: objects, totalCount: totalCount });

        case 14:
        case 'end':
          return _context3.stop();
      }
    }
  }, null, this);
}