'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.nodeField = exports.nodeInterface = undefined;
exports.swapiTypeToGraphQLType = swapiTypeToGraphQLType;

var _apiHelper = require('./apiHelper');

var _graphqlRelay = require('graphql-relay');

/**
 * Given a "type" in SWAPI, returns the corresponding GraphQL type.
 */

/**
 *  Copyright (c) 2015, Facebook, Inc.
 *  All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 */

function swapiTypeToGraphQLType(swapiType) {
  var FilmType = require('./types/film').default;
  var PersonType = require('./types/person').default;
  var PlanetType = require('./types/planet').default;
  var SpeciesType = require('./types/species').default;
  var StarshipType = require('./types/starship').default;
  var VehicleType = require('./types/vehicle').default;

  switch (swapiType) {
    case 'films':
      return FilmType;
    case 'people':
      return PersonType;
    case 'planets':
      return PlanetType;
    case 'starships':
      return StarshipType;
    case 'vehicles':
      return VehicleType;
    case 'species':
      return SpeciesType;
  }
}

var _nodeDefinitions = (0, _graphqlRelay.nodeDefinitions)(function (globalId) {
  var _fromGlobalId = (0, _graphqlRelay.fromGlobalId)(globalId);

  var type = _fromGlobalId.type;
  var id = _fromGlobalId.id;

  return (0, _apiHelper.getObjectFromTypeAndId)(type, id);
}, function (obj) {
  var parts = obj.url.split('/');
  return swapiTypeToGraphQLType(parts[parts.length - 3]);
});

var nodeInterface = _nodeDefinitions.nodeInterface;
var nodeField = _nodeDefinitions.nodeField;
exports.nodeInterface = nodeInterface;
exports.nodeField = nodeField;