'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _graphql = require('graphql');

var _graphqlRelay = require('graphql-relay');

var _relayNode = require('../relayNode');

var _commonFields = require('../commonFields');

var _connections = require('../connections');

var _film = require('./film');

var _film2 = _interopRequireDefault(_film);

var _person = require('./person');

var _person2 = _interopRequireDefault(_person);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * The GraphQL type equivalent of the Planet resource
 */
var PlanetType = new _graphql.GraphQLObjectType({
  name: 'Planet',
  description: 'A large mass, planet or planetoid in the Star Wars Universe, at the time of\n0 ABY.',
  fields: function fields() {
    return {
      name: {
        type: _graphql.GraphQLString,
        description: 'The name of this planet.'
      },
      diameter: {
        type: _graphql.GraphQLInt,
        description: 'The diameter of this planet in kilometers.'
      },
      rotationPeriod: {
        type: _graphql.GraphQLInt,
        resolve: function resolve(planet) {
          return planet.rotation_period;
        },
        description: 'The number of standard hours it takes for this planet to complete a single\nrotation on its axis.'
      },
      orbitalPeriod: {
        type: _graphql.GraphQLInt,
        resolve: function resolve(planet) {
          return planet.orbital_period;
        },
        description: 'The number of standard days it takes for this planet to complete a single orbit\nof its local star.'
      },
      gravity: {
        type: _graphql.GraphQLString,
        description: 'A number denoting the gravity of this planet, where "1" is normal or 1 standard\nG. "2" is twice or 2 standard Gs. "0.5" is half or 0.5 standard Gs.'
      },
      population: {
        type: _graphql.GraphQLInt,
        description: 'The average population of sentient beings inhabiting this planet.'
      },
      climates: {
        type: new _graphql.GraphQLList(_graphql.GraphQLString),
        resolve: function resolve(planet) {
          return planet.climate.split(',').map(function (s) {
            return s.trim();
          });
        },
        description: 'The climates of this planet.'
      },
      terrains: {
        type: new _graphql.GraphQLList(_graphql.GraphQLString),
        resolve: function resolve(planet) {
          return planet.terrain.split(',').map(function (s) {
            return s.trim();
          });
        },
        description: 'The terrains of this planet.'
      },
      surfaceWater: {
        type: _graphql.GraphQLFloat,
        resolve: function resolve(planet) {
          return planet.surface_water;
        },
        description: 'The percentage of the planet surface that is naturally occuring water or bodies\nof water.'
      },
      residentConnection: (0, _connections.connectionFromUrls)('PlanetResidents', 'residents', _person2.default),
      filmConnection: (0, _connections.connectionFromUrls)('PlanetFilms', 'films', _film2.default),
      created: (0, _commonFields.createdField)(),
      edited: (0, _commonFields.editedField)(),
      id: (0, _graphqlRelay.globalIdField)('planets')
    };
  },
  interfaces: function interfaces() {
    return [_relayNode.nodeInterface];
  }
});
/**
 *  Copyright (c) 2015, Facebook, Inc.
 *  All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 */

exports.default = PlanetType;